@@ -19,13 +19,16 @@ ContractsMessageFactory = MessageFactory(u'contract')
 
 try:
     from plonehrm.contracts import validators
+    validators  # pyflakes
 except AlreadyRegisteredValidatorError:
     pass
 
 
 def initialize(context):
     import content
+    content  # pyflakes
     from content import tool
+    tool  # pyflakes
 
     content_types, constructors, ftis = process_types(
         listTypes(config.PROJECTNAME),
@@ -33,8 +36,8 @@ def initialize(context):
 
     cmfutils.ContentInit(
         config.PROJECTNAME + ' Content',
-        content_types      = content_types,
-        permission         = 'plonehrm: Add contract',
-        extra_constructors = constructors,
-        fti                = ftis,
-        ).initialize(context)
+        content_types=content_types,
+        permission='plonehrm: Add contract',
+        extra_constructors=constructors,
+        fti=ftis,
+    ).initialize(context)
