@@ -1,6 +1,8 @@
 __author__ = """Jean-Paul Ladage <j.ladage@zestsoftware.nl>"""
 __docformat__ = 'plaintext'
 
-# # Classes
+# Classes
 import contract
 import letter
+
+contract, letter  # pyflakes
