@@ -1,7 +1,6 @@
 import logging
 
-from zope.component import queryMultiAdapter
-from Products.CMFCore.utils import getToolByName
+from Products.plonehrm.utils import apply_template_of_tool
 
 logger = logging.getLogger('plonehrm.contracts.events')
 
@@ -13,29 +12,7 @@ def apply_template(object, event, rename=True):
     setting its title.  Within tests this may fail, so there it can
     help to set it to False.  Yes, this is a hack.
     """
-    view = queryMultiAdapter((object, object.REQUEST),
-                             name=u'substituter')
-    if view is None:
-        raise ValueError('Components are not properly configured, could '
-                         'not find "substituter" view')
-
-    tool = getToolByName(object, 'portal_contracts', None)
-    if tool is None:
-        logger.error("portal_contracts cannot be found.")
-        return
-
-    # Get the text from the template
-    pages = [t for t in tool.listTemplates()
-                     if t.getId() == object.template]
-    if not pages:
-        logger.warn("Template %r cannot be found." % object.template)
-        return
-    template_page = pages[0]
-    template_text = template_page.getText()
-
-    # Save the substituted text on the object.
-    resulting_text = view.substitute(template_text)
-    object.setText(resulting_text)
+    template_page = apply_template_of_tool(object, 'portal_contracts')
 
     # Set the title to the title of the template (appending 1, 2,
     # 3...), if it has not been set explicitly.
@@ -46,7 +23,7 @@ def apply_template(object, event, rename=True):
     if employee is not None:
         numbers = [0]
         for contract in employee.getFolderContents(
-            dict(portal_type=object.portal_type)):
+                dict(portal_type=object.portal_type)):
             if not contract.Title.startswith(title):
                 continue
             number = contract.Title.split(' ')[-1]
