@@ -50,16 +50,34 @@ class IContract(Interface):
 
     def getDaysPerWeek():
         """ """
-        
+
     def setDaysPerWeek():
         """ """
-    
+
     def getTemplate():
         """ """
 
     def setTemplate():
         """ """
 
+    def getContractIsFixedDuration():
+        """Get isFixedDuration from contract.
+
+        For letters get the value from the matching contract.
+        """
+
+    def getContractDuration():
+        """Get duration from contract.
+
+        For letters get the value from the matching contract.
+        """
+
+    def getContractExpirydate():
+        """Get expiry datefrom contract.
+
+        For letters get the value from the matching contract.
+        """
+
 
 class ILetter(IContract):
     """An official letter"""
