@@ -1,6 +1,5 @@
 import unittest
 from Testing import ZopeTestCase as ztc
-from zope.testing import doctest
 from plonehrm.contracts.tests.base import BaseTestCase
 
 
@@ -8,12 +7,17 @@ def test_suite():
     return unittest.TestSuite([
         # Integration tests that use PloneTestCase
         ztc.ZopeDocFileSuite(
-                'doc/contracts-technical.txt', package='plonehrm.contracts',
-                test_class=BaseTestCase),
+            'doc/contracts-technical.txt', package='plonehrm.contracts',
+            test_class=BaseTestCase),
+
+        ztc.ZopeDocFileSuite(
+            'doc/checkers.txt', package='plonehrm.contracts',
+            test_class=BaseTestCase),
+
         ztc.ZopeDocTestSuite(
-                module='plonehrm.contracts.content.tool',
-                test_class=BaseTestCase),
-        ])
+            module='plonehrm.contracts.content.tool',
+            test_class=BaseTestCase),
+    ])
 
 
 if __name__ == '__main__':
